#
# spec file for package targetcli-fb
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           targetcli-fb
Version:        2.1.49
Release:        lp151.2.10.1
Summary:        A command shell for managing the Linux LIO kernel target
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/open-iscsi/%{name}
Source:         %{name}-%{version}.tar.xz
Source1:        %{name}.service
BuildRequires:  %{python_module configshell-fb}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module rtslib-fb}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  systemd
Requires:       python-configshell-fb
Requires:       python-dbus-python
Requires:       python-rtslib-fb
Requires:       python-six
Requires:       targetcli-fb-common
Requires(post): update-alternatives
Requires(postun): update-alternatives
%ifpython3
Provides:       targetcli    = %{version}-%{release}
Provides:       targetcli-fb = %{version}-%{release}
%endif
Obsoletes:      targetcli
Obsoletes:      targetcli-fb
BuildArch:      noarch
%if 0%{?sle_version} >= 150000
# explicit Provides advertising RBD support
Provides:       targetcli-rbd = %{version}
Obsoletes:      targetcli-rbd < %{version}
%endif
%{?systemd_requires}
Patch1:         Split-out-blockdev-readonly-state-detection-helper.patch
Patch2:         rbd-support.patch
Patch3:         saveconfig-compress-the-backup-config-files
Patch4:         targetcli-fb-fix-raise-exception-error-in-save_backups
Patch5:         Add-emulate_pr-backstore-attribute.patch
Patch6:         do-not-remove-the-first-digit-when-auto-completing-the-tpg-tag
Patch7:         iscsi-discovery_auth-enable-is-a-number-not-a-string
Patch11:        saveconfig-set-0o600-perms-on-backupfiles.patch
Patch12:        saveconfig-set-right-perms-on-backup-dir.patch
Patch13:        saveconfig-set-right-perms-on-etc-target-dir.patch

%python_subpackages

%description
targetcli-fb is a command-line interface for configuring the LIO generic
SCSI target, present in 3.x Linux kernel versions.

targetcli-fb is a fork of the "targetcli" code written by RisingTide Systems.
The "-fb" differentiates between the original and this version. Please ensure
to use either all "fb" versions of the targetcli components -- targetcli,
rtslib, and configshell, or stick with all non-fb versions, since they are
no longer strictly compatible.

%package -n %{name}-common
Summary:        Common targetcli-fb subpackage for either flavor of Python
Group:          System/Management
Provides:       %{python_module targetcli-fb-common}

%description -n %{name}-common
targetcli-fb-common is the invariant base package needed by both
python2-targetcli-fb and python3-targetcli-fb.

%prep
%setup -q
%patch1 -p1
%if 0%{?sle_version} >= 150000
# RBD support is dependent on LIO changes present in the SLE/Leap kernel
%patch2 -p1
%endif
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/targetcli
install -d -m755 %{buildroot}%{_sysconfdir}/target
install -d -m755 %{buildroot}%{_sysconfdir}/target/backup
install -d -m755 %{buildroot}%{_sbindir}
install -D -m644 targetcli.8 %{buildroot}%{_mandir}/man8/targetcli.8
install -D -m644 %{SOURCE1} %{buildroot}%{_unitdir}/targetcli.service
%fdupes %{buildroot}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rctargetcli

%post
%python_install_alternative targetcli

%postun
%python_uninstall_alternative targetcli

%pre
%{service_add_pre targetcli.service}

%preun
%{stop_on_removal targetcli}

%post -n %{name}-common
%{service_add_post targetcli.service}

%postun -n %{name}-common
%{service_del_postun targetcli.service}

%pre -n %{name}-common
%{service_add_pre targetcli.service}

%preun -n %{name}-common
%{service_del_preun targetcli.service}

%files %{python_files}
%python_alternative %{_bindir}/targetcli
%{python_sitelib}/*

%files -n %{name}-common
%license COPYING
%doc README.md THANKS
%dir %{_sysconfdir}/target
%dir %{_sysconfdir}/target/backup
%doc %{_mandir}/man8/targetcli.8%{ext_man}
%{_unitdir}/targetcli.service
%{_sbindir}/rctargetcli

%changelog
* Fri Jun 26 2020 Lee Duncan <lduncan@suse.com>
- Tighten permissions on backup and config files (bsc#1172743
  CVE-2020-13867), adding patches from upstream:
  * saveconfig-set-0o600-perms-on-backupfiles.patch
  * saveconfig-set-right-perms-on-backup-dir.patch
  * saveconfig-set-right-perms-on-etc-target-dir.patch
* Tue Aug 20 2019 Lee Duncan <lduncan@suse.com>
- Added the following upstream patches, with descriptions, in case
  the names aren't obvious enough:
  * targetcli-fb-fix-raise-exception-error-in-save_backups
  - fixes an error with an exception that can be raised for backups
  * iscsi-discovery_auth-enable-is-a-number-not-a-string (bsc#1145685)
  - The /iscsi discovery_uath "enable" variable is a number, not
    a string, so treat it as such
  * saveconfig-compress-the-backup-config-files
  - For saveconfig, compress the backup config files
  * do-not-remove-the-first-digit-when-auto-completing-the-tpg-tag
  - Do not remove the first digit when auto-commpleting the TPG tag
  Please see the patches themselves for more information.
* Wed Apr  3 2019 ddiss@suse.com
- support emulate_pr attribute changes (bsc#1121998)
  + Add-emulate_pr-backstore-attribute.patch
* Thu Feb  7 2019 lduncan@suse.com
- Ensure this package and the deprecated lio-utils package
  do not run at the same time, in a sane way (bsc#1123423),
  updating the source file targetcli-fb.service. Also, updated
  the SPEC file with new year, updated URL, and http->https.
* Fri Dec  7 2018 ddiss@suse.com
- Enable RBD support for SLE/Leap 15+ (bsc#1118516)
* Thu Oct 18 2018 opensuse-packaging@opensuse.org
- Update to version 2.1.49:
  * version 2.1.fb49
  * targetcli-fb: Add support for media change
  * fix the parameter of define_config_group_param
  * saveconfig: handle backups with block-level delete
  * saveconfig: way for block-level save with delete command
  * create: add a way to set control string
  * fix amount of backup files in backup dir
  * config: add saveconfig command to StorageObject level
  * Allow to customize a home directory
  * Fix default max_backup_files in ui_command_saveconfig
  * MappedLuns and Luns max number is not the same anymore
  * Use signed char instead of char
  * version 2.1.fb48
  * remove wrong exit code from targetcli --version
  * backup: global option to tune max no. of backup conf files
  * config: rename key 'kept_backups' as 'max_backup_files'
  * config: backup when current config is different from recent backup copy
  * config: defend on '/etc/target/backup' directory
  * Auto-detect readonly state for iblock devices
  * Read number of backup files to keep from file
  * skip refreshing user backed storage object when it is null
  * Replace dbus-python with GObject Introspection
  This replaces targetcli-fb-2.1.47.tar.xz with targetcli-fb-2.1.49.tar.xz,
  and removes the following patches:
  * Auto-detect-readonly-state-for-iblock-devices.patch
  * Use-signed-char-instead-of-char.patch
  * targetcli-only-save-old-config-if-present.patch
  and updates the SPEC file.
* Fri Apr 20 2018 lduncan@suse.com
- Only save current config to backup if current
  config exists (bsc#1090424), adding patch:
  * targetcli-only-save-old-config-if-present.patch
* Wed Apr 11 2018 ddiss@suse.com
- Merge RBD support from non-fb version (bsc#1079329)
  + Split-out-blockdev-readonly-state-detection-helper.patch
  + rbd-support.patch (SLE/Leap only, due to LIO kernel dependency)
  + Add explicit Provides for "python-rtslib-rbd"
- Detect write-protected block devices (bsc#1070815)
  + Auto-detect-readonly-state-for-iblock-devices.patch
  + Use-signed-char-instead-of-char.patch
* Tue Apr 10 2018 ddiss@suse.com
- Automatically generate version string from upstream tag
  + Retain current fb-removed version format used
  + Rename targetcli-fb-2.1.fb47.tar.xz to targetcli-fb-2.1.47.tar.xzar.xz
    and cleanup hardcoded duplicate name/version values in spec
* Sun Feb 25 2018 olaf@aepfle.de
- Fix upgrade path by provide/obsolete targetcli/targetcli-fb (bsc#1082693)
* Mon Feb  5 2018 olaf@aepfle.de
- Fix upgrade path by provide/obsolete version-release
* Mon Jan 15 2018 lduncan@suse.com
- Removed duplicate BuildRequires line, and add Conflicts for
  sub-package
* Thu Jan  4 2018 lduncan@suse.com
- Added dependency on dbus package to SPEC file (bsc#1073913)
* Thu Jan  4 2018 lduncan@suse.com
- Converted RPM SPEC file to singlepsec format (bsc#1045332),
  updating SPEC file only. This breaks this package into two
  packages. The new base package is called targetcli-fb-common,
  and does not depend on the python version. The other package
  is python-version dependent, and is called either
  python2-targetcli-fb or python3-targetcli-fb, dpending on
  which version of Python you wish to use.
* Fri Dec 15 2017 lduncan@suse.com
- Ran "spec-cleaner" over the SPEC file, to clean it up, before
  support for Python3 is added.
* Fri Dec 15 2017 lduncan@suse.com
- Moved targetcli-fb-2.1.fb47.tar.gz to targetcli-fb-2.1.fb47.tar.xz,
  after appropriate decompression/compression, to match SPEC and
  _service file. Updated _servicedata to match.
* Thu Aug 17 2017 lszhu@suse.com
- Update to version 2.1.fb47
  * Improving ALUA and TCMU support, as well as moving the default
  directory for APTPL files from /var/target to /etc/target,
  for better FHS compliance.
* Thu Apr 13 2017 hare@suse.com
- Update to version 2.1.fb46 (bsc#1032833):
  * version 2.1.fb44
  * Remove build scripts for RPM and Debian packages
  * Add Gentoo to the list of distributions that ship targetcli-fb
  * Add support to create/delete ALUA groups on a storage object
  * Add support to set/get a LUN's ALUA group
  * version 2.1.fb45
  * Create ALUA dir and def group in UI with storage object
  * Clear backstore cache on refresh
  * version 2.1.fb46
* Sun Oct 30 2016 jengelh@inai.de
- Trim macro indirections and empty macros
* Mon Jul 25 2016 lduncan@suse.com
-  updated spec file: removed Provides/Obsoletes of
  targetcli and python-targetcli, and added
  Conflicts with targetcli (bsc#986475)
* Tue Apr 19 2016 lduncan@suse.com
- Creating from latest upstream version 2.1.fb43
